#!/bin/bash

###conf : a adpater
#Chemin du ou du rep de log
PATH_LOG='log'
#Nom du streamer jar : dépend de votre version
STREAM_JAR_NAME="hadoop-streaming-1.0.0.jar"

#Variable d’environnement de travail
APP_PATH=$(readlink -f $(dirname $0))
YEAR=$( date "+%Y" )
MONTH=$( date "+%m" )
DAY=$( date "+%d" )
MIN=$( date "+%M" )
SECOND=$( date "+%S" )
DATE_START=${YEAR}${MONTH}${DAY}
RANDOM_NAME=${DATE_START}${MIN}${SECOND}'-'$RANDOM

#Home d’installation d’hadoop suivant la partie 1 du tuto
HADOOP_HOME_BIN='/opt/hadoop-1.0.0/'

#Création du répertoire de travail sur le HDFS
HDFS_INPUT='input/'$RANDOM_NAME
echo "Création du répertoire de travail : $HDFS_INPUT"
$HADOOP_HOME_BIN/bin/hadoop fs -mkdir $HDFS_INPUT

#On dépose le ou les fichiers de log a traiter
echo "Copie du log $PATH_LOG sur le hdfs $PATH_LOG pour le traitement"
$HADOOP_HOME_BIN/bin/hadoop fs -put $PATH_LOG/* $HDFS_INPUT

#Définition du répertoire où sera entreposé le résulta du Job.
#Attention ! il ne faut pas le créer : Hadoop se chargera de le faire
HDFS_OUTPUT='OUTPUT/'$RANDOM_NAME

#Définition du répertoire de stockage
HDFS_STORAGE='STORAGE/'$DATE_START
echo "Création du répertoire de stockage"
$HADOOP_HOME_BIN/bin/hadoop fs -mkdir $HDFS_STORAGE

#Map Reduce en action
echo "Lancement de MAP / REDUCE"
$HADOOP_HOME_BIN/bin/hadoop jar \
$HADOOP_HOME_BIN/contrib/streaming/$STREAM_JAR_NAME \
-input $HDFS_INPUT \
-output $HDFS_OUTPUT \
-mapper map.php \
-reducer reduce.php \
-file $APP_PATH/map.php \
-file $APP_PATH/reduce.php &
wait %1
STATUS=$?
#Tout c’est bien passé on va bouger le résultat dans notre répertoire de stockage
if [ $STATUS -eq 0 ]
then
    #on copie le résulta dans notre entrepôt et on le renomme
    echo "Copie du résulta $RANDOM_NAME du traitement dans $HDFS_STORAGE"
    $HADOOP_HOME_BIN/bin/hadoop fs -cp $HDFS_OUTPUT/part-* $HDFS_STORAGE/$RANDOM_NAME
    #On sup le répertoire de travail & de sortie
    echo "Supp de l'environnement de travail"
    $HADOOP_HOME_BIN/bin/hadoop fs -rmr $HDFS_INPUT/
    $HADOOP_HOME_BIN/bin/hadoop fs -rmr $HDFS_OUTPUT

    $HADOOP_HOME_BIN/bin/hadoop fs -ls $HDFS_STORAGE
else
    echo "pb avec le Map & Reduce"
fi